@@ -628,6 +628,22 @@ def algoinfo(maadstoken,maads_rest_url,pkey,username='',passw='',company='',emai
    
     return msg
 
+def nlpgeosentiment(maadstoken,maads_rest_url,lat,long,radius,searchterms,numtweets=50,wordcount=300,username='',passw='',company='',email=''):
+    files = {'mode':'nlpgeosentiment',        
+        'lat': lat,
+        'long': long,
+        'radius': radius,
+        'searchterms': searchterms,
+        'numtweets': numtweets,
+        'wordcount': wordcount,             
+        'maadstoken':maadstoken
+      }
+
+    r = requests.post(maads_rest_url, files)
+    msg = r.text
+   
+    return msg
+
 def featureselectionjson(maadstoken,maads_rest_url,pkey,username='',passw='',company='',email=''):
     files = {'mode':'featureselection',        
         'username': username,
